package config

var defaultLoggingConfig = &LogConfig{
	Enabled:    true,
	Level:      "info",
	Format:     LogFormatJSON,
	Output:     "stderr",
	TimeFormat: TimeFormatLong,
}

// Logging Configuration
type LogConfig struct {
	Enabled    bool       `yaml:"enabled,omitempty" env:"APP_LOG_ENABLED" json:"enabled,omitempty"`
	Level      string     `yaml:"level,omitempty" env:"APP_LOG_LEVEL" json:"level,omitempty"`
	Format     LogFormat  `yaml:"format,omitempty" env:"APP_LOG_FORMAT" json:"format,omitempty"`
	Output     LogOutput  `yaml:"output,omitempty" env:"APP_LOG_OUTPUT" json:"output,omitempty"`
	TimeFormat TimeFormat `yaml:"timeFormat,omitempty" env:"APP_LOG_TIME_FORMAT" json:"timeFormat,omitempty"`
}

type LogFormat string

const (
	LogFormatConsole LogFormat = "console"
	LogFormatJSON    LogFormat = "json"
)

type TimeFormat string

const (
	TimeFormatShort   TimeFormat = "short"
	TimeFormatLong    TimeFormat = "long"
	TimeFormatUnix    TimeFormat = "unix"
	TimeFormatRFC3339 TimeFormat = "rfc3339"
	TimeFormatOff     TimeFormat = "off"
)

type LogOutput string

const (
	LogOutputStdout LogOutput = "stdout"
	LogOutputStderr LogOutput = "stderr"
)
